<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AppDialog</name>
    <message>
        <source>Published Applications</source>
        <translation>Applications publiées</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Rechercher:</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;Démarrer</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Éducation</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphismes</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Préférences</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation type="unfinished">Accessoires</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autres</translation>
    </message>
</context>
<context>
    <name>BrokerPassDialogUi</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old password:</source>
        <translation type="unfinished">Ancien mot de passe:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation type="unfinished">Nouveau mot de passe:</translation>
    </message>
    <message>
        <source>Confirm password:</source>
        <translation type="unfinished">Confirmez le mot de passe:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="unfinished">TextLabel</translation>
    </message>
</context>
<context>
    <name>BrokerPassDlg</name>
    <message>
        <source>Passwords do not match</source>
        <translation type="unfinished">Les mots de passe ne correspondent pas</translation>
    </message>
</context>
<context>
    <name>CUPSPrintWidget</name>
    <message>
        <source>Idle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing</source>
        <translation type="unfinished">En cours d&apos;impression</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation type="unfinished">Arrêté</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Non</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished">Formulaire</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished">Nom:</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="unfinished">Propriétés</translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished">État:</translation>
    </message>
    <message>
        <source>Accepting jobs:</source>
        <translation type="unfinished">En attentes de travaux:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Type:</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation type="unfinished">Emplacement:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation type="unfinished">Commentaire:</translation>
    </message>
</context>
<context>
    <name>CUPSPrinterSettingsDialog</name>
    <message>
        <source>No option selected</source>
        <translation type="unfinished">Pas d&apos;options séléctionnées</translation>
    </message>
    <message>
        <source>This value is in conflict with other option</source>
        <translation type="unfinished">Cette valeur est en conflit avec une autre option</translation>
    </message>
    <message>
        <source>Options conflict</source>
        <translation type="unfinished">Conflits d&apos;options</translation>
    </message>
</context>
<context>
    <name>ConTest</name>
    <message>
        <source>Connectivity test</source>
        <translation>Test de connectivité</translation>
    </message>
    <message>
        <source>HTTPS connection:</source>
        <translation>Connection HTTPS:</translation>
    </message>
    <message>
        <source>SSH connection:</source>
        <translation>Connection SSH:</translation>
    </message>
    <message>
        <source>Connection speed:</source>
        <translation>Vitesse de connection:</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échec</translation>
    </message>
    <message>
        <source>0 Kb/s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Socket operation timed out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed: </source>
        <translation>Échec:</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Display icon in system tray</source>
        <translation>Afficher l&apos;icone dans la barre des tâches</translation>
    </message>
    <message>
        <source>Hide to system tray when minimized</source>
        <translation>Cacher dans la barre des tâches à la réduction de la fenêtre</translation>
    </message>
    <message>
        <source>Hide to system tray when closed</source>
        <translation>Cacher dans la barre des tâches à la fermeture de la fenêtre</translation>
    </message>
    <message>
        <source>Hide to system tray after connection is established</source>
        <translation>Cacher dans la barre des tâches quand la session est établie</translation>
    </message>
    <message>
        <source>Restore from system tray after session is disconnected</source>
        <translation>Cacher dans la barre des tâches quand la session est déconnectée</translation>
    </message>
    <message>
        <source>Use LDAP</source>
        <translation>Utiliser LDAP</translation>
    </message>
    <message>
        <source>Server URL:</source>
        <translation>URL du serveur:</translation>
    </message>
    <message>
        <source>BaseDN:</source>
        <translation>BaseDN:</translation>
    </message>
    <message>
        <source>Failover server 1 URL:</source>
        <translatorcomment>Failover en backup ?</translatorcomment>
        <translation type="unfinished">URL du premier serveur de backup:</translation>
    </message>
    <message>
        <source>Failover server 2 URL:</source>
        <translation type="unfinished">URL du second serveur de backup:</translation>
    </message>
    <message>
        <source>X-Server settings</source>
        <translation>Préférences du serveur X</translation>
    </message>
    <message>
        <source>X11 application:</source>
        <translation>Applications X11:</translation>
    </message>
    <message>
        <source>X11 version:</source>
        <translation>Version X11:</translation>
    </message>
    <message>
        <source>Find X11 application</source>
        <translation>Trouver une application X11</translation>
    </message>
    <message>
        <source>Clientside SSH port for file system export usage:</source>
        <translation>Port SSH coté client pour l&apos;export du système de fichiers:</translation>
    </message>
    <message>
        <source>Start session embedded inside website</source>
        <translation type="unfinished">Démarrer une session embarquée dans le site web</translation>
    </message>
    <message>
        <source>Advanced options</source>
        <translation>Options avancées</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Défauts</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>Printing</source>
        <translation>Impression</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Attention</translation>
    </message>
    <message>
        <source>x2goclient could not find any suitable X11 Application. Please install Apple X11 or select the path to the application</source>
        <translation>x2goclient ne peut pas trouve d&apos;application X11 adaptée. Merci d&apos;installer Apple X11 ou de séléctionner le chemin de l&apos;application</translation>
    </message>
    <message>
        <source>Your are using X11 (Apple X-Window Server) version </source>
        <translation>Vous utilisez X11 (Server X-Window Apple) version </translation>
    </message>
    <message>
        <source>. This version causes problems with X-application in 24bit color mode. You should update your X11 environment (http://trac.macosforge.org/projects/xquartz).</source>
        <translation>Cette version pose des problèmes avec les applications X en mode de couleurs 24bits. Vous devriez mettre à jour votre environement X11 (http://trac.macosforge.org/projects/xquartz).</translation>
    </message>
    <message>
        <source>No suitable X11 application found in selected path</source>
        <translation>Pas d&apos;application X11 trouvée dans le chemin sélectionné.</translation>
    </message>
    <message>
        <source>&amp;Connection</source>
        <translation>&amp;Connection</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Préférences</translation>
    </message>
</context>
<context>
    <name>ConnectionWidget</name>
    <message>
        <source>&amp;Connection speed</source>
        <translation>Vitesse de &amp;connection</translation>
    </message>
    <message>
        <source>Connection speed:</source>
        <translation>Vitesse de connection:</translation>
    </message>
    <message>
        <source>C&amp;ompression</source>
        <translatorcomment>C&amp;ompression</translatorcomment>
        <translation type="unfinished">C&amp;ompression</translation>
    </message>
    <message>
        <source>Method:</source>
        <translation>Méthode:</translation>
    </message>
    <message>
        <source>Compression method:</source>
        <translation>Méthode de compression:</translation>
    </message>
    <message>
        <source>Image quality:</source>
        <translation>Qualité d&apos;image:</translation>
    </message>
</context>
<context>
    <name>CupsPrinterSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Page size:</source>
        <translation>Taille de page:</translation>
    </message>
    <message>
        <source>Paper type:</source>
        <translation>Type de papier:</translation>
    </message>
    <message>
        <source>Paper source:</source>
        <translation>Source de papier:</translation>
    </message>
    <message>
        <source>Duplex Printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Long side</source>
        <translation>Bord long</translation>
    </message>
    <message>
        <source>Short side</source>
        <translation>Bord court</translation>
    </message>
    <message>
        <source>Driver settings</source>
        <translation>Préférences de pilote</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
    <message>
        <source>No option selected</source>
        <translation>Pas d&apos;option sélectionnée</translation>
    </message>
    <message>
        <source>text</source>
        <translation>texte</translation>
    </message>
</context>
<context>
    <name>EditConnectionDialog</name>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Session</translation>
    </message>
    <message>
        <source>&amp;Connection</source>
        <translation>&amp;Connection</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <source>&amp;Shared folders</source>
        <translation>&amp;Dossiers partagés</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Défauts</translation>
    </message>
    <message>
        <source>Session preferences - </source>
        <translation type="unfinished">Préférences de session - </translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;share</source>
        <translation>&amp;Partager</translation>
    </message>
    <message>
        <source>&amp;Preferences ...</source>
        <translation>&amp;Préférences ...</translation>
    </message>
    <message>
        <source>&amp;Custom folder ...</source>
        <translation>&amp;Dossier personnalisé ...</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete</comment>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>share folders</source>
        <translation>partager des dossiers</translation>
    </message>
    <message>
        <source>Select folder</source>
        <translation>Choisir un dossier</translation>
    </message>
</context>
<context>
    <name>HttpBrokerClient</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Login failed!&lt;br&gt;Please try again</source>
        <translation>Identification échouée !&lt;br&gt;Merci de réessayer</translation>
    </message>
    <message>
        <source>Host key for server changed.
It is now: </source>
        <translation>La clef du serveur a changée.
C&apos;est maintenant: </translation>
    </message>
    <message>
        <source>For security reasons, connection will be stopped</source>
        <translation>Pour des raisons de sécurité, la connection va être stoppée.</translation>
    </message>
    <message>
        <source>The host key for this server was not found but an othertype of key exists.An attacker might change the default server key toconfuse your client into thinking the key does not exist</source>
        <translation type="unfinished">La clef de ce serveur n&apos;a pas été trouvée mais un autre type de clef existe. Un attaquant peut avoir changé la clef par défaut du serveur pour faire croire à votre client que la clef n&apos;existe pas</translation>
    </message>
    <message>
        <source>Could not find known host file.If you accept the host key here, the file will be automatically created</source>
        <translation>Impossible de trouver le fichier des hôtes connus. Si vous acceptez l&apos;hôte maintenant, le fichier sera créé automatiquement</translation>
    </message>
    <message>
        <source>The server is unknown. Do you trust the host key?
Public key hash: </source>
        <translation>Le serveur n&apos;est pas connu. Avez-vous confiance en cette clef ? Hash de la clef publique: </translation>
    </message>
    <message>
        <source>Host key verification failed</source>
        <translation>La vérification de la clef d&apos;hôte a échouée</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Enter passphrase to decrypt a key</source>
        <translation>Entrez la phrase de passe pour déchiffrer la clef</translation>
    </message>
    <message>
        <source>Authentication failed</source>
        <translation>Identification échouée</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;b&gt;Server uses an invalid security certificate.&lt;/b&gt;&lt;br&gt;&lt;br&gt;</source>
        <translation>&lt;br&gt;&lt;b&gt;Le serveur utilise un certificat de sécurité invalide.&lt;/b&gt;&lt;br&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;p style=&apos;background:#FFFFDC;&apos;&gt;You should not add an exception if you are using an internet connection that you do not trust completely or if you are not used to seeing a warning for this server.&lt;/p&gt;</source>
        <translation>&lt;p style=&apos;background:#FFFFDC;&apos;&gt;Vous ne devriez pas ajouter d&apos;exeption si vous n&apos;avez pas une entière confiance en la connection Internet que vous utilisez ou si vous n&apos;avez pas l&apos;habitude de voir cet avertissement pour ce serveur.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Secure connection failed</source>
        <translation>Connection sécurisée échouée</translation>
    </message>
    <message>
        <source>Issued to:
</source>
        <translation>Accordé à:</translation>
    </message>
    <message>
        <source>Common Name(CN)	</source>
        <translation>Common Name(CN)</translation>
    </message>
    <message>
        <source>Organization(O)	</source>
        <translation>Organization(O)</translation>
    </message>
    <message>
        <source>Organizational Unit(OU)	</source>
        <translation>Organizational Unit(OU)</translation>
    </message>
    <message>
        <source>Serial Number	</source>
        <translation>Numéro de série</translation>
    </message>
    <message>
        <source>Issued by:
</source>
        <translation>Accordé par:</translation>
    </message>
    <message>
        <source>Validity:
</source>
        <translation>Validité:</translation>
    </message>
    <message>
        <source>Issued on	</source>
        <translation>Accordé sur</translation>
    </message>
    <message>
        <source>expires on	</source>
        <translation>expire le</translation>
    </message>
    <message>
        <source>Fingerprints:
</source>
        <translation>Fingerprints:</translation>
    </message>
    <message>
        <source>SHA1	</source>
        <translation>SHA1</translation>
    </message>
    <message>
        <source>MD5	</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>Exit X2Go Client</source>
        <translation>Quitter X2Go Client</translation>
    </message>
    <message>
        <source>Add exception</source>
        <translation>Ajouter une exception</translation>
    </message>
</context>
<context>
    <name>ONMainWindow</name>
    <message>
        <source>us</source>
        <translation>us</translation>
    </message>
    <message>
        <source>pc105/us</source>
        <translation type="obsolete">pc105/us</translation>
    </message>
    <message>
        <source>X2Go Client</source>
        <translation>X2Go Client</translation>
    </message>
    <message>
        <source>connecting</source>
        <translation>Connection en cours</translation>
    </message>
    <message>
        <source>Internet browser</source>
        <translation>Navigateur Internet</translation>
    </message>
    <message>
        <source>Email client</source>
        <translation>Client e-mail</translation>
    </message>
    <message>
        <source>OpenOffice.org</source>
        <translation>OpenOffice.org</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <source>&amp;Settings ...</source>
        <translation>&amp;Préférences ...</translation>
    </message>
    <message>
        <source>Support ...</source>
        <translation>Support ...</translation>
    </message>
    <message>
        <source>About X2GO client</source>
        <translation>Apropos de X2Go Client</translation>
    </message>
    <message>
        <source>Share folder...</source>
        <translation>Partager le dossier...</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <source>Terminate</source>
        <translation>Terminer</translation>
    </message>
    <message>
        <source>Reconnect</source>
        <translation>Reconnecter</translation>
    </message>
    <message>
        <source>Detach X2Go window</source>
        <translation>Détacher la fenêtre X2Go</translation>
    </message>
    <message>
        <source>Minimize toolbar</source>
        <translation>Réduire la barre d&apos;outils</translation>
    </message>
    <message>
        <source>Session:</source>
        <translation>Session:</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quiter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;New session ...</source>
        <translation>&amp;Nouvelle session ...</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Session management...</source>
        <translation>Gestion de sessions...</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Create session icon on desktop...</source>
        <translation>&amp;Créer une icone de session sur le bureau...</translation>
    </message>
    <message>
        <source>&amp;Set broker password...</source>
        <translation>Configurer le mot de passe du broker...</translation>
    </message>
    <message>
        <source>&amp;Connectivity test...</source>
        <translation>Test de &amp;Connectivité...</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <comment>exit</comment>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Session</source>
        <translation>&amp;Session</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Options</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Login:</source>
        <translation>Identifiant:</translation>
    </message>
    <message>
        <source>Operation failed</source>
        <translation>Opération échouée</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>Mot de passe modifié</translation>
    </message>
    <message>
        <source>Wrong password!</source>
        <translation>Mauvais mot de passe !</translation>
    </message>
    <message>
        <source>&lt;b&gt;Authentication&lt;/b&gt;</source>
        <translation>&lt;b&gt;Identification&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Réstauration</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation></translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Éducation</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphismes</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>Accessoires</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Left mouse button to hide/restore - Right mouse button to display context menu</source>
        <translation>Bouton de gauche de la souris pour cacher/afficher - Bouton de droite de la souris pour afficher le menu contextuel</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Please check LDAP settings</source>
        <translation>Merci de vérifier les réglages LDAP</translation>
    </message>
    <message>
        <source>no X2Go server found in LDAP </source>
        <translation>Pas de serveur X2Go trouvé dans LDAP</translation>
    </message>
    <message>
        <source>Create session icon on desktop</source>
        <translation>Créer une icone de session sur le bureau</translation>
    </message>
    <message>
        <source>Desktop icons can be configured not to show x2goclient (hidden mode). If you like to use this feature you&apos;ll need to configure login by a gpg key or gpg smart card.

Use x2goclient hidden mode?</source>
        <translation>Les icones de bureau peuvent être configurées pour ne pas afficher X2Go Client (mode caché). Si vous voulez utiliser cette fonctionnalité, vous aurez besoin de configurer l&apos;identification par clef GPG ou par Smart Card GPG.

Utiliser le mode caché de X2Go Client ?</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nouvelle session</translation>
    </message>
    <message>
        <source>X2Go Link to session </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X2Go sessions not found</source>
        <translation type="obsolete">Sessions X2Go non trouvées</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this session?</source>
        <translation>Êtes vous sûr de vouloir effacer cette session ?</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation></translation>
    </message>
    <message>
        <source>RDP connection</source>
        <translation>Connection RDP</translation>
    </message>
    <message>
        <source>XDMCP</source>
        <translation></translation>
    </message>
    <message>
        <source>Connection to local desktop</source>
        <translation>Connection au bureau local</translation>
    </message>
    <message>
        <source> on </source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;b&gt;Connection failed&lt;/b&gt;
</source>
        <translation>&lt;b&gt;Connection échouée&lt;/b&gt;
</translation>
    </message>
    <message>
        <source>&lt;b&gt;Wrong password!&lt;/b&gt;&lt;br&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Mauvais mot de passe !&lt;/b&gt;&lt;br&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>inconnu</translation>
    </message>
    <message>
        <source>No server availabel</source>
        <translation>Pas de serveur disponible</translation>
    </message>
    <message>
        <source>Select session:</source>
        <translation>Sélectionnez la session:</translation>
    </message>
    <message>
        <source>running</source>
        <translation>en cours</translation>
    </message>
    <message>
        <source>suspended</source>
        <translation>suspendue</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <source>single application</source>
        <translation>application simple</translation>
    </message>
    <message>
        <source>shadow session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>No accessible desktop found</source>
        <translation>Aucun bureau distant trouvé</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Select desktop:</source>
        <translation>Selectionnez un bureau:</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <source>Your current color depth is different to the color depth of your x2go-session. This may cause problems reconnecting to this session and in most cases &lt;b&gt;you will loose the session&lt;/b&gt; and have to start a new one! It&apos;s highly recommended to change the color depth of your Display to </source>
        <translation>La profondeur de couleur de votre serveur X est différente de celle de votre session X2Go. Cela peut pauser problème pour se reconnecter et la plupart du temps, &lt;b&gt;vous allez perdre la session&lt;/b&gt;. Vous êtes fortement encouragé à changer la profondeur de couleur de couleur de votre serveur X à </translation>
    </message>
    <message>
        <source>24 or 32</source>
        <translation>24 ou 32</translation>
    </message>
    <message>
        <source> bit and restart your X-server before you reconnect to this x2go-session.&lt;br&gt;Resume this session anyway?</source>
        <translation>bits et redémarrer votre serveur X avant de vous reconnecter à votre session.&lt;br&gt;Souhaitez-vous tout de même rétablir cette session ?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>Enter passphrase to decrypt a key</source>
        <translation>Entrez une phrase de passe pour déchiffrer une clef</translation>
    </message>
    <message>
        <source>Host key for server changed.
It is now: </source>
        <translation>La clef d&apos;hôte du serveur a changée.
La nouvelle clef est:</translation>
    </message>
    <message>
        <source>For security reasons, connection will be stopped</source>
        <translation type="obsolete">Pour des raisons de sécurité, la connection va être stoppée</translation>
    </message>
    <message>
        <source>The host key for this server was not found but an othertype of key exists.An attacker might change the default server key toconfuse your client into thinking the key does not exist</source>
        <translation type="obsolete">La clef d&apos;hôte pour ce serveur n&apos;a pas été trouvée mais un autre type de clef a été trouvé. Un attaquant peut avoir changé la clef par défaut du serveur pour faire croire à votre client que la clef n&apos;existe pas</translation>
    </message>
    <message>
        <source>Could not find known host file.If you accept the host key here, the file will be automatically created</source>
        <translation>Impossible de trouver le fichier des hôtes connus. Si vouss acceptez la clef d&apos;hôte ici, le fichier sera automatiquement créé</translation>
    </message>
    <message>
        <source>The server is unknown. Do you trust the host key?
Public key hash: </source>
        <translation>Le serveur est inconnu. Avez vous confiance en la clef d&apos;hôte ?
Hash de la clef publique: </translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Host key verification failed</source>
        <translation>La vérification de la clef d&apos;hôte a échouée</translation>
    </message>
    <message>
        <source>Authentication failed</source>
        <translation>L&apos;autentification a échouée</translation>
    </message>
    <message>
        <source>Enter password for SSH proxy</source>
        <translation>Entrez un mot de passe pour le proxy SSH</translation>
    </message>
    <message>
        <source>Server not availabel</source>
        <translation>Le serveur n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>suspending</source>
        <translation type="unfinished">suspension</translation>
    </message>
    <message>
        <source>terminating</source>
        <translation type="unfinished">en train de se terminer</translation>
    </message>
    <message>
        <source>&lt;b&gt;Wrong Password!&lt;/b&gt;&lt;br&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Mauvais mot de passe !&lt;/b&gt;&lt;br&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Unable to create folder:</source>
        <translation>Impossible de créer le dossier:</translation>
    </message>
    <message>
        <source>Unable to write file:</source>
        <translation type="obsolete">Impossible de créer le fichier:</translation>
    </message>
    <message>
        <source>Attach X2Go window</source>
        <translation>Atacher la fenêtre X2Go</translation>
    </message>
    <message>
        <source>Unable to create SSL tunnel:
</source>
        <translation>Impossible de créer un tunnel SSL:</translation>
    </message>
    <message>
        <source>Unable to create SSL Tunnel:
</source>
        <translation>Impossible de créer un tunnel SSL:</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Fini</translation>
    </message>
    <message>
        <source>starting</source>
        <translation>démarrage</translation>
    </message>
    <message>
        <source>resuming</source>
        <translation>rétablissement</translation>
    </message>
    <message>
        <source>Connection timeout, aborting</source>
        <translation>Connection expirée, abandon en cours</translation>
    </message>
    <message>
        <source>aborting</source>
        <translation>abandon en cours</translation>
    </message>
    <message>
        <source>Are you sure you want to terminate this session?
Unsaved documents will be lost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Connection failed&lt;/b&gt;
:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> (can&apos;t open file)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> (file not exists)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> (directory not exists)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--link&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--sound&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--geometry&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--set-kbd&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--ldap&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--ldap1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--ldap2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;--pack&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available pack methodes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;/b&gt;&lt;br&gt; (C. 2005-2014 &lt;b&gt;obviously nice&lt;/b&gt;: Oleksandr Shneyder, Heinz-Markus Graesing)&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;x2goplugin mode was sponsored by &lt;a href=&quot;http://www.foss-group.de/&quot;&gt;FOSS-Group GmbH(Freiburg)&lt;/a&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;Client for use with the X2Go network based computing environment. This Client will be able to connect to X2Go server(s) and start, stop, resume and terminate (running) desktop sessions. X2Go Client stores different server connections and may automatically request authentication data from LDAP directories. Furthermore it can be used as fullscreen loginscreen (replacement for loginmanager like xdm). Please visit x2go.org for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;X2Go Client V. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please check LDAP Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid card found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This card is unknown by X2Go system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t start X server
Please check your settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t connect to X server
Please check your settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t start X Server
Please check your installation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to execute: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote server does not support file system export through SSH Tunnel
Please update to a newer x2goserver package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read :
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to write :
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X2Go Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard layout:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Session ID:&lt;br&gt;Server:&lt;br&gt;Username:&lt;br&gt;Display:&lt;br&gt;Creation time:&lt;br&gt;Status:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Applications...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client IP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only my desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sshd not started, you&apos;ll need sshd for printing and file sharing
you can install sshd with
&lt;b&gt;sudo apt-get install openssh-server&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;b&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;Click this button&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;br&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;to restore toolbar&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;/b&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting to broker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WINDOWS-1252</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ISO8859-1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>wrong value for argument&quot;speed&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting x2goclient...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting x2goclient in portable mode... data directory is: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Started  x2goclient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t load translator: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translator: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> installed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closing x2goclient...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closed  x2goclient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No X2Go sessions found, closing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting connection to server: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error(</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t find a SSH connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection failed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> - Wrong password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New session started</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session resumed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create folder: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to write file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Emergency exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for proxy to exit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed, killing the proxy.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wrong parameter: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSA file empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not open key: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Card not configured.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error getting window geometry (window closed)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show session tray icon when running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This can be an indication of a man-in-the-middle attack.
Somebody might be eavesdropping on you.
For security reasons, it is recommended to stop the connection.
Do you want to terminate the connection?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you accept the new host key the security of your connection may be compromised.
Do you want to update the host key?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The host key for this server was not found but an othertype of key exists. An attacker might change the default server key to confuse your client into thinking the key does not exist. 
For security reasons, it is recommended to stop the connection.
Do you want to terminate the connection?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verification code:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;ve deactivated the x2go client printing dialog.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You may reactivate this dialog using the x2goclient settings dialog (Menu -&gt; Options -&gt; Settings)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print - X2Go Client</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintProcess</name>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Document (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to execute command:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintWidget</name>
    <message>
        <source>Please configure your client side printing settings.&lt;br&gt;&lt;br&gt;If you want to print the created file, you&apos;ll need an external application. Typically you can use &lt;a href=&quot;http://pages.cs.wisc.edu/~ghost/doc/GPL/index.htm&quot;&gt;ghostprint&lt;/a&gt; and &lt;a href=&quot;http://pages.cs.wisc.edu/~ghost/gsview/&quot;&gt;ghostview&lt;/a&gt;&lt;br&gt;You can find  further information &lt;a href=&quot;http://www.x2go.org/index.php?id=49&quot;&gt;here&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="unfinished">Formulaire</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View as PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print using default Windows PDF Viewer
(Viewer application needs to be installed)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Viewer settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open in viewer application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this dialog before start printing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrinterCmdDialog</name>
    <message>
        <source>Please enter your customized or individual printing command.
Example:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;Path to gsprint.exe&gt; -query -color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter your customized or individual printing command.
Examples:
kprinter
lpr -P hp_laserjet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose the printing file format (regarding to your printing environment - if you use CUPS you may use PDF)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data structure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please choose the method of printing file input (some commands accepting printing files as program options, some are awaiting data on standard input):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>standard input (STDIN)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify path as program parameter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No response received from the remote server. Do you want to terminate the current session?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionButton</name>
    <message>
        <source>Session preferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create session icon on desktop...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle sound support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Session</source>
        <translation type="unfinished">Nouvelle session</translation>
    </message>
    <message>
        <source>running</source>
        <translation type="unfinished">en cours</translation>
    </message>
    <message>
        <source>suspended</source>
        <translation type="unfinished">suspendue</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDP connection</source>
        <translation type="unfinished">Connection RDP</translation>
    </message>
    <message>
        <source>XDMCP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection to local desktop</source>
        <translation type="unfinished">Connection au bureau local</translation>
    </message>
    <message>
        <source>Published applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionManageDialog</name>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Session preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Create session icon on desktop...</source>
        <translation type="unfinished">&amp;Créer une icone de session sur le bureau...</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete</comment>
        <translation type="unfinished">Effacer</translation>
    </message>
    <message>
        <source>Session management</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>Session name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;&lt; change icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Login:</source>
        <translation type="unfinished">Identifiant:</translation>
    </message>
    <message>
        <source>SSH port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use RSA/DSA key for ssh connection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Try auto login (ssh-agent or default ssh key)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kerberos 5 (GSSAPI) authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Proxy server for SSH connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same login as on X2Go Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same password as on X2Go Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSA/DSA key:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ssh-agent or default ssh key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Type:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Session type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to Windows terminal server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XDMCP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect to local desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Published applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Direct RDP Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDP port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XDMCP server:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rdesktop command line options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Erreur</translation>
    </message>
    <message>
        <source>x2goclient is running in portable mode. You should use a path on your usb device to be able to access your data whereever you are</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delegation of GSSAPI credentials to the server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDP Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use whole display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set display DPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xinerama extension (support for two or more physical displays)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Identify all displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sound support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start sound daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use running sound daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use SSH port forwarding to tunnel
sound system connections through firewalls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use default sound port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client side printing support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Additional parameters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command line:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>us</source>
        <translation type="unfinished">us</translation>
    </message>
    <message>
        <source>pc105/us</source>
        <translation type="obsolete">pc105/us</translation>
    </message>
    <message>
        <source>password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto detect keyboard settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not configure keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Model: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Layout: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Variant: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShareWidget</name>
    <message>
        <source>&amp;Folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Effacer</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ssh port forwarding to tunnel file system connections through firewalls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select folder</source>
        <translation type="unfinished">Choisir un dossier</translation>
    </message>
    <message>
        <source>Filename encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WINDOWS-1252</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ISO8859-1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>local:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>remote:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Erreur</translation>
    </message>
    <message>
        <source>x2goclient is running in portable mode. You should use a path on your usb device to be able to access your data whereever you are</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SshMasterConnection</name>
    <message>
        <source>SSH proxy connection error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH proxy connection error: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to create SSH proxy tunnel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not initialize libssh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not create ssh session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not connect to proxy server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not connect to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel_forward_listen failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not open file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not create remote file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not write to remote file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>can not connect to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel_open_forward failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel_open_session failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel_request_exec failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error writing to socket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error reading channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel_write failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error reading tcp socket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to start SSH Client. Please check your installation and GSSApi configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check your GSSApi configuration or choose another authentication method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SshProcess</name>
    <message>
        <source>Error creating socket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error binding </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XSettingsWidget</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Executable (*.exe)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XSettingsWidgetUI</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Formulaire</translation>
    </message>
    <message>
        <source>You must restart the X2Go Client for the changes to take effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>use integrated X-Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>use custom X-Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>custom X-Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>executable:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>start X-Server on X2Go Client start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>command line options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X-Server command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>window mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fullscreen mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>single application:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> do not use primary clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
